@@ -490,7 +490,7 @@ def _eintr_retry_call(func, *args):
     while True:
         try:
             return func(*args)
-        except (OSError, IOError), e:
+        except (OSError, IOError) as e:
             if e.errno == errno.EINTR:
                 continue
             raise
