@@ -14,7 +14,8 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from utils.text import convertStrListDict
+from __future__ import absolute_import
+from .utils.text import convertStrListDict
 from calculate.lib.configparser import ConfigParser
 from collections import defaultdict
 
