@@ -14,6 +14,7 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
+from __future__ import absolute_import
 import sys
 import os
 import hashlib
@@ -27,8 +28,8 @@ try:
     from smbpasswd import lmhash, nthash
 except ImportError:
     lmhash, nthash = None, None
-from cl_print import color_print
-import cl_overriding
+from .cl_print import color_print
+from . import cl_overriding
 from calculate.contrib.passlib.hash import sha256_crypt, grub_pbkdf2_sha512
 
 from calculate.lib.cl_lang import setLocalTranslate
