@@ -14,9 +14,10 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from files import (process, checkUtils, readFile, listDirectory,
+from __future__ import absolute_import
+from .files import (process, checkUtils, readFile, listDirectory,
                    getRunCommands, getProgPath, FilesError)
-import device
+from . import device
 import sys
 import os
 import re
