@@ -25,9 +25,11 @@ from calculate.lib.cl_lang import setLocalTranslate
 _ = lambda x: x
 setLocalTranslate('cl_lib3', sys.modules[__name__])
 
-_u = lambda t: t.decode('UTF-8', 'replace') if isinstance(t, str) else t
+# _u = lambda t: t.decode('UTF-8', 'replace') if isinstance(t, str) else t
+_u = lambda t: t if isinstance(t, str) else t
 _uu = lambda *tt: tuple(_u(t) for t in tt)
-_u8 = lambda t: t.encode('UTF-8', 'replace') if isinstance(t, unicode) else t
+# _u8 = lambda t: t.encode('UTF-8', 'replace') if isinstance(t, str) else t
+_u8 = lambda t: t  if isinstance(t, str) else t
 _uu8 = lambda *tt: tuple(_u8(t) for t in tt)
 
 
@@ -267,6 +269,7 @@ class MultiReplace:
     def __init__(self, repl_dict):
         # string to string mapping; use a regular expression
         keys = repl_dict.keys()
+        keys = list(keys)
         keys.sort(reverse=True)  # lexical order
         pattern = u"|".join([re.escape(key) for key in keys])
         self.pattern = re.compile(pattern)
@@ -367,10 +370,10 @@ def dict2str(dict):
 def convertStrListDict(val):
     """Convert data between string, list, dict"""
     # if val is list
-    if isinstance(val, types.ListType):
+    if isinstance(val, list):
         return list2str(val)
     # if val is dictionary
-    elif isinstance(val, types.DictType):
+    elif isinstance(val, dict):
         return dict2str(val)
     # else it is string
     else:
