@@ -14,16 +14,18 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
+from __future__ import print_function
 from itertools import tee
 from functools import total_ordering, wraps
 import warnings
 from contextlib import contextmanager
 import re
 import sys
-from types import StringTypes
+# from types import StringTypes
 import os
 import fcntl
 from os import path
+import errno
 import time
 from abc import ABCMeta, abstractmethod
 from types import GeneratorType
@@ -58,7 +60,7 @@ class SavableIterator:
         return self
 
     def next(self):
-        return self.seq.next()
+        return next(self.seq)
 
 
 @contextmanager
@@ -203,14 +205,14 @@ def classificate(iterator):
             return "Mark(first=%s,last=%s)" % (self.first, self.last)
 
     iterator = iter(iterator)
-    obj = iterator.next()
+    obj = next(iterator)
     try:
-        obj_next = iterator.next()
+        obj_next = next(iterator)
         yield Mark(first=True, last=False), obj
         try:
             while True:
                 obj = obj_next
-                obj_next = iterator.next()
+                obj_next = next(iterator)
                 yield Mark(), obj
         except StopIteration:
             yield Mark(first=False, last=True), obj
@@ -228,7 +230,7 @@ def debug(prefix="DEBUG {name}({args},{kw})={ret}"):
         @wraps(f)
         def wrapper(*args, **kw):
             ret = f(*args, **kw)
-            print prefix.format(name=f.func_name, args=args, kw=kw, ret=ret)
+            print(prefix.format(name=f.__name__, args=args, kw=kw, ret=ret))
             return ret
 
         return wrapper
@@ -305,13 +307,13 @@ class Locker(object):
                 self.lockf = os.open(fn, os.O_CREAT | os.O_RDWR)
                 fcntl.flock(self.lockf, fcntl.LOCK_EX | fcntl.LOCK_NB)
                 return True
-            except IOError, e:
-                if e.errno != os.errno.EAGAIN:
+            except IOError as e:
+                if e.errno != errno.EAGAIN:
                     raise e
                 os.close(self.lockf)
                 self.lockf = None
-            except OSError, e:
-                if e.errno != os.errno.EEXIST:
+            except OSError as e:
+                if e.errno != errno.EEXIST:
                     raise e
             time.sleep(0.25)
         else:
@@ -463,7 +465,7 @@ def iterate_list(l):
     :param l: Список, кортеж, или прочее
     :return:
     """
-    if not isinstance(l, StringTypes):
+    if not isinstance(l, str):
         for x in l:
             yield x
     else:
@@ -526,7 +528,7 @@ class Cachable(object):
         можно выбрать какие параметры играют роль
         """
         def decorator(f):
-            funcname = f.func_name
+            funcname = f.__name__
 
             @wraps(f)
             def wrapper(self, *args, **kw):
@@ -545,7 +547,7 @@ class Cachable(object):
                 if funcname not in self._method_cache:
                     self._method_cache[funcname] = f(self)
                 return self._method_cache[funcname]
-            if len(f.func_code.co_varnames) > 1:
+            if len(f.__code__.co_varnames) > 1:
                 return wrapper
             else:
                 return null_wrapper
